@@ -1,11 +1,11 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.006';
+$Class::Type::Enum::VERSION = '0.007';
 
 use strict;
 use warnings;
 
-use Function::Parameters ':strict';
+use Function::Parameters 2;
 use List::Util 1.33;
 use Scalar::Util qw(blessed);
 use Class::Method::Modifiers qw(install_modifier);
@@ -20,7 +20,7 @@ use overload (
 
 
 
-fun import ($class, %params) {
+method import ($class: %params) {
   # import is inherited, but we don't want to do all this to everything that
   # uses a subclass of Class::Type::Enum.
   return unless $class eq __PACKAGE__;
@@ -49,13 +49,13 @@ fun import ($class, %params) {
   install_modifier $target, 'fresh', sym_to_ord => sub { \%values };
   install_modifier $target, 'fresh', ord_to_sym => sub { +{ reverse(%values) } };
 
-  install_modifier $target, 'fresh', values => method {
+  install_modifier $target, 'fresh', values => method () {
     my $ord = $self->sym_to_ord;
     [ sort { $ord->{$a} <=> $ord->{$b} } keys %values ];
   };
 
   for my $value (keys %values) {
-    install_modifier $target, 'fresh', "is_$value" => method { $self->is($value) };
+    install_modifier $target, 'fresh', "is_$value" => method () { $self->is($value) };
   }
 }
 
@@ -123,12 +123,12 @@ method is ($value) {
 
 
 
-method stringify {
+method stringify ($, $) {
   $self->ord_to_sym->{$self->{ord}};
 }
 
 
-method numify {
+method numify ($, $) {
   $self->{ord}
 }
 
@@ -159,7 +159,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ Meredith Howard <mhoward@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Meredith Howard.
+This software is copyright (c) 2017 by Meredith Howard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
